huhu
===================
## * This Project Under Development *

### Installation

pip install huhu

### If you don't have pip:

easy_install pip

### Syntax

```sh

* set
değişken = bu bir değişken

* list
liste = bu, bir, liste

* write
yaz(değişken)

* looping
yaz(kelime dön kelimeler)

* range
sayilar = 1..8
yaz(sayi) dön sayilar

harfler = a..z
yaz(harf) dön harfler

```
if you have any clean syntax idea, please create an issue for discussion.
